#include <iostream>
#include <vector>
#include <map>
#include <algorithm>
#include <string>
#include <random>

#define int long long

struct pt{
    int x, y, z;

    int dist(pt a) {
        return std::abs(x - a.x) + std::abs(y - a.y) + std::abs(z - a.z);
    }
};

struct DSU{
    std::vector<int> sz, par;
    DSU(int n) {
        sz.resize(n), par.resize(n);
        for (int i = 0; i < n; ++i) {
            sz[i] = 1, par[i] = i;
        }
    }

    int get(int v) {
        if (par[v] == v) {
            return v;
        }
        return par[v] = get(par[v]);
    }

    void unite(int v, int u) {
        v = get(v);
        u = get(u);
        if (v == u) {
            return;
        }
        if (sz[u] > sz[v]) {
            std::swap(v, u);
        }
        par[u] = v;
        sz[v] += sz[u];
        return;
    }
};

std::vector<pt> vertex;

void gen() {
    std::map<std::pair<std::pair<int, int>, int>, bool> used;
    int x = rand() % 10, y = rand() % 10, z = rand() % 10;
    used[{{x + 1, y + 1}, z + 1}] = true;
    int n = (rand() % 7) + 1;
    vertex.push_back({x + 1, y + 1, z + 1});
    for (int i = 0; i < n; ++i) {
        x = rand() % 10, y = rand() % 10, z = rand() % 10;
        while (used[{{x + 1, y + 1}, z + 1}]) {
            x = rand() % 10, y = rand() % 10, z = rand() % 10;
        }
        used[{{x + 1, y + 1}, z + 1}] = true;
        vertex.push_back({x + 1, y + 1, z + 1});
    }
}

std::vector<int> vec_ans;

int good(std::vector<pt> vertex) {
    std::vector<int> order(vertex.size() - 1);
    for (int i = 0; i < (int)vertex.size() - 1; ++i) {
        order[i] = i + 1;
    }
    int min_ans = 1e9;
    //std::vector<int> vec_ans;
    do {
        int cur_ans = 0;
        cur_ans += vertex[0].dist(vertex[order[0]]);
        //std::cout << vertex[0].dist(vertex[order[0]]) << std::endl;
        for (int i = 0; (int)i < order.size() - 1; ++i) {
            //std::cout << order[i] << " ";
            cur_ans += vertex[order[i]].dist(vertex[order[i + 1]]);
        }
        //std::cout << cur_ans << std::endl;
        if (cur_ans < min_ans) {
            min_ans = cur_ans;
            vec_ans = order;
        }
    } while (std::next_permutation(order.begin(), order.end()));
    //std::cout << min_ans << '\n';
    return min_ans;
    /*for (auto elem : vec_ans) {
        std::cout << elem << '\n';
    }*/
}

signed main() {
    std::ios_base::sync_with_stdio(0);
    std::cin.tie(0);
    std::cout.tie(0);


    pt st;
    std::cin >> st.x >> st.y >> st.z;
    vertex.push_back(st);
    int n;
    std::cin >> n;
    for (int i = 0; i < n; ++i) {
        pt cur;
        std::cin >> cur.x >> cur.y >> cur.z;
        vertex.push_back(cur);
    }
    if (n <= 10) {
        int ans = good(vertex);
        std::cout << ans << '\n';
        for (auto elem : vec_ans) {
            std::cout << elem << '\n';
        }
        return 0;
    }
    std::vector<bool> used(vertex.size());
    int cur = 0;
    used[0] = true;
    bool flag = true;
    std::vector<int> ans_vec;
    int ans = 0;
    while (flag) {
        int cur_min = -1;
        int min = 1e9;
        for (int i = 0; i < vertex.size(); ++i) {
            if (used[i]) continue;
            if (vertex[cur].dist(vertex[i]) < min) {
                min = vertex[cur].dist(vertex[i]);
                cur_min = i;
            }
        }
        if (cur_min == -1) {
            break;
        }
        used[cur_min] = true;
        //std::cout << cur_min << '\n';
        ans_vec.push_back(cur_min);
        ans += min;
        cur = cur_min;
    }
    std::cout << ans << '\n';
    for (auto elem : ans_vec) {
        std::cout << elem << '\n';
    }



}